@@ -9,8 +9,8 @@ from aporia.as_code.stack import Stack
 
 # Consts
 from aporia.sdk.data_sources import DataSourceType
-from aporia.sdk.datasets import DatasetType
-from aporia.sdk.models import ModelColor, ModelIcon, ModelType, ModelAggregationPeriod
+from aporia.sdk.datasets import DatasetType, SortOrder
+from aporia.sdk.models import ModelAggregationPeriod, ModelColor, ModelIcon, ModelType
 from aporia.sdk.monitors import (
     AverageMethod,
     BaselineConfiguration,
