@@ -795,7 +795,7 @@ def add_model(stack: aporia.Stack):
 
             if error is not None:
                 if debug:
-                    traceback.print_exception(error)
+                    traceback.print_exception(error, tb=error.__traceback__, value=error)
                 else:
                     print(error)
                 if rollback:
@@ -805,7 +805,7 @@ def add_model(stack: aporia.Stack):
                             error = self._destroy()
                             if error is not None:
                                 if debug:
-                                    traceback.print_exception(error)
+                                    traceback.print_exception(error, tb=error.__traceback__, value=error)
                                 else:
                                     print(error)
         elif action is StackAction.PREVIEW:
@@ -822,7 +822,7 @@ def add_model(stack: aporia.Stack):
             error = self._destroy()
             if error is not None:
                 if debug:
-                    traceback.print_exception(error)
+                    traceback.print_exception(error, tb=error.__traceback__, value=error)
                 else:
                     print(error)
         elif action is StackAction.DIFF:
